==> angular__compiler-2.0.0-rc.6.jar: META-INF/resources/webjars/angular__compiler/2.0.0-rc.6/src/private_import_core.d.ts <==
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import { __core_private__ as r } from '@angular/core';
export declare const isDefaultChangeDetectionStrategy: typeof r.isDefaultChangeDetectionStrategy;
export declare type ChangeDetectorStatus = typeof r._ChangeDetectorStatus;
export declare const ChangeDetectorStatus: typeof r.ChangeDetectorStatus;
export declare type LifecycleHooks = typeof r._LifecycleHooks;
export declare const LifecycleHooks: typeof r.LifecycleHooks;
export declare const LIFECYCLE_HOOKS_VALUES: typeof r.LIFECYCLE_HOOKS_VALUES;
export declare type ReflectorReader = typeof r._ReflectorReader;
export declare const ReflectorReader: typeof r.ReflectorReader;
export declare type AppElement = typeof r._AppElement;
export declare const AppElement: typeof r.AppElement;
export declare const CodegenComponentFactoryResolver: typeof r.CodegenComponentFactoryResolver;
export declare const AppView: typeof r.AppView;
export declare const DebugAppView: typeof r.DebugAppView;
export declare const NgModuleInjector: typeof r.NgModuleInjector;
export declare type ViewType = typeof r._ViewType;
export declare const ViewType: typeof r.ViewType;
export declare const MAX_INTERPOLATION_VALUES: typeof r.MAX_INTERPOLATION_VALUES;
export declare const checkBinding: typeof r.checkBinding;
export declare const flattenNestedViewRenderNodes: typeof r.flattenNestedViewRenderNodes;
export declare const interpolate: typeof r.interpolate;
export declare const ViewUtils: typeof r.ViewUtils;
export declare const DebugContext: typeof r.DebugContext;
export declare const StaticNodeDebugInfo: typeof r.StaticNodeDebugInfo;
export declare const devModeEqual: typeof r.devModeEqual;
export declare const UNINITIALIZED: typeof r.UNINITIALIZED;
export declare const ValueUnwrapper: typeof r.ValueUnwrapper;
export declare const TemplateRef_: typeof r.TemplateRef_;
export declare type RenderDebugInfo = typeof r._RenderDebugInfo;
export declare const RenderDebugInfo: typeof r.RenderDebugInfo;
export declare const EMPTY_ARRAY: typeof r.EMPTY_ARRAY;
export declare const EMPTY_MAP: typeof r.EMPTY_MAP;
export declare const pureProxy1: typeof r.pureProxy1;
export declare const pureProxy2: typeof r.pureProxy2;
export declare const pureProxy3: typeof r.pureProxy3;
export declare const pureProxy4: typeof r.pureProxy4;
export declare const pureProxy5: typeof r.pureProxy5;
export declare const pureProxy6: typeof r.pureProxy6;
export declare const pureProxy7: typeof r.pureProxy7;
export declare const pureProxy8: typeof r.pureProxy8;
export declare const pureProxy9: typeof r.pureProxy9;
export declare const pureProxy10: typeof r.pureProxy10;
export declare const castByValue: typeof r.castByValue;
export declare type Console = typeof r._Console;
export declare const Console: typeof r.Console;
export declare const reflector: typeof r.reflector;
export declare const Reflector: typeof r.Reflector;
export declare type Reflector = typeof r._Reflector;
export declare type ReflectionCapabilities = typeof r._ReflectionCapabilities;
export declare const ReflectionCapabilities: typeof r.ReflectionCapabilities;
export declare type NoOpAnimationPlayer = typeof r._NoOpAnimationPlayer;
export declare const NoOpAnimationPlayer: typeof r.NoOpAnimationPlayer;
export declare type AnimationPlayer = typeof r._AnimationPlayer;
export declare const AnimationPlayer: typeof r.AnimationPlayer;
export declare type AnimationSequencePlayer = typeof r._AnimationSequencePlayer;
export declare const AnimationSequencePlayer: typeof r.AnimationSequencePlayer;
export declare type AnimationGroupPlayer = typeof r._AnimationGroupPlayer;
export declare const AnimationGroupPlayer: typeof r.AnimationGroupPlayer;
export declare type AnimationKeyframe = typeof r._AnimationKeyframe;
export declare const AnimationKeyframe: typeof r.AnimationKeyframe;
export declare type AnimationStyles = typeof r._AnimationStyles;
export declare const AnimationStyles: typeof r.AnimationStyles;
export declare type AnimationOutput = typeof r._AnimationOutput;
export declare const AnimationOutput: typeof r.AnimationOutput;
export declare const ANY_STATE: string;
export declare const DEFAULT_STATE: string;
export declare const EMPTY_STATE: string;
export declare const FILL_STYLE_FLAG: string;
export declare const prepareFinalAnimationStyles: typeof r.prepareFinalAnimationStyles;
export declare const balanceAnimationKeyframes: typeof r.balanceAnimationKeyframes;
export declare const clearStyles: typeof r.clearStyles;
export declare const collectAndResolveStyles: typeof r.collectAndResolveStyles;
export declare const renderStyles: typeof r.renderStyles;
export declare type ViewMetadata = typeof r._ViewMetadata;
export declare const ViewMetadata: typeof r.ViewMetadata;
export declare type ComponentStillLoadingError = typeof r._ComponentStillLoadingError;
export declare const ComponentStillLoadingError: typeof r.ComponentStillLoadingError;

==> angular__compiler-2.0.2.jar: META-INF/resources/webjars/angular__compiler/2.0.2/src/private_import_core.d.ts <==
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import { __core_private__ as r } from '@angular/core';
export declare const isDefaultChangeDetectionStrategy: typeof r.isDefaultChangeDetectionStrategy;
export declare type ChangeDetectorStatus = typeof r._ChangeDetectorStatus;
export declare const ChangeDetectorStatus: typeof r.ChangeDetectorStatus;
export declare type LifecycleHooks = typeof r._LifecycleHooks;
export declare const LifecycleHooks: typeof r.LifecycleHooks;
export declare const LIFECYCLE_HOOKS_VALUES: typeof r.LIFECYCLE_HOOKS_VALUES;
export declare type ReflectorReader = typeof r._ReflectorReader;
export declare const ReflectorReader: typeof r.ReflectorReader;
export declare type AppElement = typeof r._AppElement;
export declare const AppElement: typeof r.AppElement;
export declare const CodegenComponentFactoryResolver: typeof r.CodegenComponentFactoryResolver;
export declare const AppView: typeof r.AppView;
export declare const DebugAppView: typeof r.DebugAppView;
export declare const NgModuleInjector: typeof r.NgModuleInjector;
export declare const registerModuleFactory: typeof r.registerModuleFactory;
export declare type ViewType = typeof r._ViewType;
export declare const ViewType: typeof r.ViewType;
export declare const MAX_INTERPOLATION_VALUES: typeof r.MAX_INTERPOLATION_VALUES;
export declare const checkBinding: typeof r.checkBinding;
export declare const flattenNestedViewRenderNodes: typeof r.flattenNestedViewRenderNodes;
export declare const interpolate: typeof r.interpolate;
export declare const ViewUtils: typeof r.ViewUtils;
export declare const DebugContext: typeof r.DebugContext;
export declare const StaticNodeDebugInfo: typeof r.StaticNodeDebugInfo;
export declare const devModeEqual: typeof r.devModeEqual;
export declare const UNINITIALIZED: typeof r.UNINITIALIZED;
export declare const ValueUnwrapper: typeof r.ValueUnwrapper;
export declare const TemplateRef_: typeof r.TemplateRef_;
export declare type RenderDebugInfo = typeof r._RenderDebugInfo;
export declare const RenderDebugInfo: typeof r.RenderDebugInfo;
export declare const EMPTY_ARRAY: typeof r.EMPTY_ARRAY;
export declare const EMPTY_MAP: typeof r.EMPTY_MAP;
export declare const pureProxy1: typeof r.pureProxy1;
export declare const pureProxy2: typeof r.pureProxy2;
export declare const pureProxy3: typeof r.pureProxy3;
export declare const pureProxy4: typeof r.pureProxy4;
export declare const pureProxy5: typeof r.pureProxy5;
export declare const pureProxy6: typeof r.pureProxy6;
export declare const pureProxy7: typeof r.pureProxy7;
export declare const pureProxy8: typeof r.pureProxy8;
export declare const pureProxy9: typeof r.pureProxy9;
export declare const pureProxy10: typeof r.pureProxy10;
export declare const castByValue: typeof r.castByValue;
export declare type Console = typeof r._Console;
export declare const Console: typeof r.Console;
export declare const reflector: typeof r.reflector;
export declare const Reflector: typeof r.Reflector;
export declare type Reflector = typeof r._Reflector;
export declare type ReflectionCapabilities = typeof r._ReflectionCapabilities;
export declare const ReflectionCapabilities: typeof r.ReflectionCapabilities;
export declare type NoOpAnimationPlayer = typeof r._NoOpAnimationPlayer;
export declare const NoOpAnimationPlayer: typeof r.NoOpAnimationPlayer;
export declare type AnimationPlayer = typeof r._AnimationPlayer;
export declare const AnimationPlayer: typeof r.AnimationPlayer;
export declare type AnimationSequencePlayer = typeof r._AnimationSequencePlayer;
export declare const AnimationSequencePlayer: typeof r.AnimationSequencePlayer;
export declare type AnimationGroupPlayer = typeof r._AnimationGroupPlayer;
export declare const AnimationGroupPlayer: typeof r.AnimationGroupPlayer;
export declare type AnimationKeyframe = typeof r._AnimationKeyframe;
export declare const AnimationKeyframe: typeof r.AnimationKeyframe;
export declare type AnimationStyles = typeof r._AnimationStyles;
export declare const AnimationStyles: typeof r.AnimationStyles;
export declare const ANY_STATE: string;
export declare const DEFAULT_STATE: string;
export declare const EMPTY_STATE: string;
export declare const FILL_STYLE_FLAG: string;
export declare const prepareFinalAnimationStyles: typeof r.prepareFinalAnimationStyles;
export declare const balanceAnimationKeyframes: typeof r.balanceAnimationKeyframes;
export declare const clearStyles: typeof r.clearStyles;
export declare const collectAndResolveStyles: typeof r.collectAndResolveStyles;
export declare const renderStyles: typeof r.renderStyles;
export declare type ViewMetadata = typeof r._ViewMetadata;
export declare const ViewMetadata: typeof r.ViewMetadata;
export declare type ComponentStillLoadingError = typeof r._ComponentStillLoadingError;
export declare const ComponentStillLoadingError: typeof r.ComponentStillLoadingError;
